@@ -24,6 +24,7 @@ import javax.swing.Icon;
 import uk.ac.starlink.ttools.plot.PdfGraphicExporter;
 import uk.ac.starlink.ttools.plot.Picture;
 import uk.ac.starlink.ttools.plot.Range;
+import uk.ac.starlink.ttools.plot2.config.ConfigKey;
 import uk.ac.starlink.ttools.plot2.config.ConfigMap;
 import uk.ac.starlink.ttools.plot2.data.DataStore;
 import uk.ac.starlink.ttools.plot2.data.TupleSequence;
@@ -183,22 +184,37 @@ public class PlotUtil {
     }
 
     /**
-     * Writes message through the logging system
-     * about the time a named step has taken.
+     * Writes a message through the logging system
+     * about the supplied elapsed time a named step has taken.
+     * If the elapsed time is zero, nothing is logged.
+     *
+     * @param  logger   log message destination
+     * @param  phase  name of step to log time of
+     * @param  elapsed   elapsed time to report (generally milliseconds)
+     */
+    public static void logTimeElapsed( Logger logger, String phase,
+                                       long elapsed ) {
+        if ( elapsed > 0 ) {
+            logger.info( phase + " time: " + elapsed );
+        }
+    }
+
+    /**
+     * Writes a message through the logging system
+     * about the elapsed time a named step has taken given a start time.
      * The elapsed time is presumed to be the time between the supplied
      * time and the time when this method is called.
-     * If the elapsed time is zero, nothing is logged.
+     * If the elapsed time is zero (to the nearest millisecond),
+     * nothing is logged.
      *
      * @param  logger   log message destination
      * @param  phase  name of step to log time of
      * @param  start   start {@link java.lang.System#currentTimeMillis
      *                              currentTimeMillis}
      */
-    public static void logTime( Logger logger, String phase, long start ) {
-        long time = System.currentTimeMillis() - start;
-        if ( time > 0 ) {
-            logger.info( phase + " time: " + time );
-        }
+    public static void logTimeFromStart( Logger logger, String phase,
+                                         long start ) {
+        logTimeElapsed( logger, phase, System.currentTimeMillis() - start );
     }
 
     /**
@@ -595,7 +611,6 @@ public class PlotUtil {
         if ( storedPlans != null ) {
             knownPlans.addAll( storedPlans );
         }
-        long t1 = System.currentTimeMillis();
         for ( int il = 0; il < nl; il++ ) {
             drawings[ il ] = layers[ il ]
                             .createDrawing( surface, auxRanges, paperType );
@@ -603,7 +618,6 @@ public class PlotUtil {
                                                         dataStore );
             knownPlans.add( plans[ il ] );
         }
-        PlotUtil.logTime( logger_, "Plans", t1 );
         if ( storedPlans != null ) {
             storedPlans.clear();
             storedPlans.addAll( new HashSet<Object>( Arrays.asList( plans ) ) );
@@ -907,6 +921,59 @@ public class PlotUtil {
         }
     }
 
+    /**
+     * Rounds a number to a decimal round value.
+     * The number of decimal places is determined by the size of
+     * a supplied value, epsilon.
+     * When turned into a string, the final digit should be about
+     * the same size as epsilon.   Given decimal-&gt;binary conversions
+     * and uncertain behaviour of library stringification methods like
+     * Double.toDouble() this isn't bulletproof and may require some
+     * adjustment, but it seems to work as desired most of the time.
+     *
+     * @param   x  input value
+     * @param  epsilon  indicates desired rounding amount
+     * @return  output value, presumably destined for stringification
+     */
+    public static double roundNumber( double x, double epsilon ) {
+        if ( Double.isNaN( x ) ) {
+            return x;
+        }
+        else {
+            try {
+                return Double.parseDouble( formatNumber( x, epsilon ) );
+            }
+            catch ( NumberFormatException e ) {
+                assert false : formatNumber( x, epsilon ) + " -> " + e;
+                return x;
+            }
+        }
+    }
+
+    /**
+     * Utility method to set a minimum/maximum config key pair
+     * to a given pair of minimum/maximum values.
+     * This handles suitable rounding for presentation.
+     *
+     * @param   minKey  config key for minimum value
+     * @param   maxKey  config key for maximum value
+     * @param   min     minimum value
+     * @param   max     maximum value
+     * @param   npix    number of pixels (quanta) between min and max;
+     *                  this is used to determine at what level of
+     *                  precision to round the config values
+     */
+    public static ConfigMap configLimits( ConfigKey<Double> minKey,
+                                          ConfigKey<Double> maxKey,
+                                          double min, double max,
+                                          int npix ) {
+        double epsilon = ( max - min ) / npix;
+        ConfigMap config = new ConfigMap();
+        config.put( minKey, roundNumber( min, epsilon ) );
+        config.put( maxKey, roundNumber( max, epsilon ) );
+        return config;
+    }
+
     /**
      * Returns the rectangle that results from removing the insets from
      * a given rectangle.
