@@ -233,13 +233,81 @@ public class SkySurface implements Surface {
     }
 
     /**
-     * Attempts to constructs a GridLiner object which can
-     * draw grid lines on this plot.
-     * The work is done by classes from the SkyView package.
+     * Returns the projection used by this sky surface.
+     *
+     * @return  projection
+     */
+    public Projection getProjection() {
+        return projection_;
+    }
+
+    /**
+     * Returns the rotation matrix corresponding to this view of the sky.
+     *
+     * @return  9-element rotation matrix
+     */
+    public double[] getRotation() {
+        return rotmat_;
+    }
+
+    /**
+     * Returns the zoom factor; 1 means the sky is approximately the
+     * same size as the plot bounds.
+     *
+     * @return  zoom factor
+     */
+    public double getZoom() {
+        return zoom_;
+    }
+
+    /**
+     * Returns the dimensionless X offset of the plot centre from the
+     * plot bounds centre.
+     *
+     * @return  dimensionless X offset
+     */
+    public double getOffsetX() {
+        return xoff_;
+    }
+
+    /**
+     * Returns the dimensionless Y offset of the plot centre from the
+     * plot bounds centre.
+     *
+     * @return  dimensionless Y offset
+     */
+    public double getOffsetY() {
+        return yoff_;
+    }
+
+    /**
+     * Attempts to construct a GridLiner object which can
+     * draw default grid lines on this plot.
      *
      * @return   gridliner, or null on failure
      */
     private GridLiner createGridder() {
+        return createGridder( null, sexagesimal_, crowd_ );
+    }
+
+    /**
+     * Attempts to construct a GridLiner object to draw grid lines on
+     * this plot.
+     *
+     * <p>The work is done by classes from the SkyView package.
+     *
+     * @param  rotation   additional rotation to apply to sky system
+     *                    before grid lines are plotted;
+     *                    may be null for no additional rotation
+     * @param  sexagesimal  true for sexagesimal labels, false for decimal
+     * @param  crowd   tick mark crowding factor, 1 is normal
+     * @return   gridliner, or null on failure
+     */
+    public GridLiner createGridder( Rotation rotation, boolean sexagesimal,
+                                    double crowd ) {
+        double[] rotmat = rotation == null
+                        ? rotmat_
+                        : Matrices.mmMult( rotmat_, rotation.getMatrix() );
         if ( projection_ instanceof SkyviewProjection ) {
             Projecter projecter =
                 ((SkyviewProjection) projection_).getSkyviewProjecter();
@@ -247,7 +315,7 @@ public class SkySurface implements Surface {
                                         gZoom_, 0, 0, -gZoom_ );
             Rotater rotater;
             try {
-                rotater = new Rotater( Matrices.toPal( rotmat_ ) );
+                rotater = new Rotater( Matrices.toPal( rotmat ) );
             }
             catch ( TransformationException e ) {
                 assert false;
@@ -258,8 +326,7 @@ public class SkySurface implements Surface {
                 return null;
             }
             GridLiner gl = new GridLiner( plotBounds, rotater, projecter,
-                                          scaler, sexagesimal_,
-                                          crowd_, crowd_ );
+                                          scaler, sexagesimal, crowd, crowd );
             try {
                 gl.grid();
                 return gl;
@@ -467,6 +534,35 @@ public class SkySurface implements Surface {
                             : formatPositionDec( lonRad, latRad, pixRad );
     }
 
+    /**
+     * Returns the approximate sky longitude and latitude coordinates
+     * of a given sperical position vector.
+     * They are rounded to an appropriate decimal precision
+     * for presentation to the user.
+     *
+     * @param  r3  3-element direction cosine vector
+     * @return  2-element (longitude,latitude) array giving approximate
+     *          (rounded) coordinates of the given spherical position
+     *          in degrees
+     */
+    double[] getRoundedLonLatDegrees( double[] r3 ) {
+        double pixRad = 2.0 * Math.PI / gZoom_;
+        double x = r3[ 0 ];
+        double y = r3[ 1 ];
+        double z = r3[ 2 ];
+        double latRad = Math.PI * 0.5 - Math.acos( z );
+        double lonRad = Math.atan2( y, x );
+        while ( lonRad < 0 ) {
+            lonRad += 2 * Math.PI;
+        }
+        double degFact = 180. / Math.PI;
+        double degEpsilon = degFact * pixRad * 0.1;
+        return new double[] {
+            PlotUtil.roundNumber( degFact * lonRad, degEpsilon ),
+            PlotUtil.roundNumber( degFact * latRad, degEpsilon ),
+        };
+    }
+
     /**
      * Returns the approximate solid angle covered by a screen pixel
      * in steradians.
@@ -662,7 +758,7 @@ public class SkySurface implements Surface {
     public SkyAspect flatPan( Point2D pos0, Point2D pos1 ) {
         double xoff1 = xoff_ + ( pos1.getX() - pos0.getX() ) / gScale_;
         double yoff1 = yoff_ + ( pos1.getY() - pos0.getY() ) / gScale_;
-        return createAspect( projection_, rotmat_, zoom_, xoff1, yoff1 );
+        return createAspect( rotmat_, zoom_, xoff1, yoff1 );
     }
 
     /**
@@ -677,7 +773,7 @@ public class SkySurface implements Surface {
         double zoom1 = zoom_ * factor;
         double xoff1 = xoff_ + ( pos.getX() - gXoff_ ) / gZoom_ * dz;
         double yoff1 = yoff_ + ( pos.getY() - gYoff_ ) / gZoom_ * dz;
-        return createAspect( projection_, rotmat_, zoom1, xoff1, yoff1 );
+        return createAspect( rotmat_, zoom1, xoff1, yoff1 );
     }
 
     /**
@@ -696,7 +792,7 @@ public class SkySurface implements Surface {
                                                graphicsToProjected( pos1 ) );
         return rotmat1 == null
              ? flatPan( pos0, pos1 )
-             : createAspect( projection_, rotmat1, zoom_, xoff_, yoff_ );
+             : createAspect( rotmat1, zoom_, xoff_, yoff_ );
     }
 
     /**
@@ -718,7 +814,7 @@ public class SkySurface implements Surface {
         double[] rotmat1 = projection_.projRotate( rotmat_, ppos0, ppos1 );
         return rotmat1 == null
              ? flatZoom( pos, factor )
-             : createAspect( projection_, rotmat1, zoom1, xoff_, yoff_ );
+             : createAspect( rotmat1, zoom1, xoff_, yoff_ );
     }
 
     /**
@@ -738,12 +834,12 @@ public class SkySurface implements Surface {
         Point2D.Double ppos1 = graphicsToProjected( surfCenter );
         double[] rotmat1 = projection_.projRotate( rotmat_, ppos0, ppos1 );
         if ( rotmat1 != null ) {
-            return createAspect( projection_, rotmat1, zoom1, xoff_, yoff_ );
+            return createAspect( rotmat1, zoom1, xoff_, yoff_ );
         }
         else {
             double xoff1 = - ppos0.x * zoom1;
             double yoff1 =   ppos0.y * zoom1;
-            return createAspect( projection_, rotmat_, zoom1, xoff1, yoff1 );
+            return createAspect( rotmat_, zoom1, xoff1, yoff1 );
         }
     }
 
@@ -828,7 +924,6 @@ public class SkySurface implements Surface {
      * This method contains an assertion that the returned aspect has
      * the same reflection state as this one.
      *
-     * @param  projection  sky projection
      * @param  rotmat  9-element rotation matrix
      * @param  zoom    zoom factor; 1 means the sky is approximately
      *                 the same size as plot bounds
@@ -837,8 +932,8 @@ public class SkySurface implements Surface {
      * @param  yoff  y offset of plot centre from plot bounds centre
      *               in dimensionless units; 0 is centred
      */
-    private SkyAspect createAspect( Projection proj, double[] rotmat,
-                                    double zoom, double xoff, double yoff ) {
+    private SkyAspect createAspect( double[] rotmat, double zoom,
+                                    double xoff, double yoff ) {
 
         /* Check that the reflection status of the returned aspect is the
          * same as that for this surface's aspect.  Although that's not an
@@ -848,6 +943,6 @@ public class SkySurface implements Surface {
          * same value for the aspect represented by this surface and the
          * one being generated. */
         assert Matrices.det( rotmat_ ) * Matrices.det( rotmat ) >= 0;
-        return new SkyAspect( proj, rotmat, zoom, xoff, yoff );
+        return new SkyAspect( rotmat, zoom, xoff, yoff );
     }
 }
