@@ -83,6 +83,36 @@ public class SkySurfaceFactory
        .setOptionUsage()
        .addOptionsXml();
 
+    /**
+     * Config key for the sky system used for supplying data.
+     * Note this is not used by SkySurfaceFactory, but client UI code
+     * may find it useful in conjunction with {@link #VIEWSYS_KEY}. */
+    public static final ConfigKey<SkySys> DATASYS_KEY =
+        new SkySysConfigKey(
+            new ConfigMeta( "datasys", "Data Sky System" )
+           .setShortDescription( "Sky coordinate system for supplied data" )
+           .setXmlDescription( new String[] {
+                "<p>The sky system used to interpret",
+                "supplied data longitude and latitude coordinate values.",
+                "</p>",
+                "<p>Choice of this value goes along with the",
+                "<code>" + VIEWSYS_KEY.getMeta().getShortName() + "</code>",
+                "value which specifies the view sky system.",
+                "If neither the view nor data system is specified,",
+                "plotting is carried out in a generic sky system",
+                "assumed the same between the data and the view.",
+                "But if any layers have a supplied data sky system,",
+                "there must be an explicitly or implicitly supplied",
+                "view sky system into which the data input coordinates",
+                "will be transformed.",
+                "If not supplied explicitly, the data system defaults",
+                "to the same value as the view system.",
+                "</p>",
+            } )
+            , false )
+       .setOptionUsage()
+       .addOptionsXml();
+
     /** Config key to determine whether grid lines are drawn. */
     public static final ConfigKey<Boolean> GRID_KEY =
         new BooleanConfigKey(
@@ -131,6 +161,7 @@ public class SkySurfaceFactory
         DoubleConfigKey.createTextKey(
             new ConfigMeta( LON_NAME, "Central Longitude" )
            .setShortDescription( "Longitude of plot centre" )
+           .setStringUsage( "<degrees>" )
            .setXmlDescription( new String[] {
                 "<p>Longitude of the central position of the plot",
                 "in decimal degrees.",
@@ -147,6 +178,7 @@ public class SkySurfaceFactory
         DoubleConfigKey.createTextKey(
             new ConfigMeta( LAT_NAME, "Central Latitude" )
            .setShortDescription( "Latitude of plot centre" )
+           .setStringUsage( "<degrees>" )
            .setXmlDescription( new String[] {
                 "<p>Latitude of the central position of the plot",
                 "in decimal degrees.",
@@ -163,6 +195,7 @@ public class SkySurfaceFactory
         DoubleConfigKey.createTextKey(
             new ConfigMeta( FOV_RADIUS_NAME, "Radius" )
            .setShortDescription( "Field of view radius in degrees" )
+           .setStringUsage( "<degrees>" )
            .setXmlDescription( new String[] {
                 "<p>Approximate radius of the plot field of view in degrees.",
                 "Only used if <code>" + LON_NAME + "</code>",
@@ -173,7 +206,7 @@ public class SkySurfaceFactory
 
     public Surface createSurface( Rectangle plotBounds, Profile p,
                                   SkyAspect aspect ) {
-        return new SkySurface( plotBounds, aspect.getProjection(),
+        return new SkySurface( plotBounds, p.getProjection(),
                                aspect.getRotation(), aspect.getZoom(),
                                aspect.getOffsetX(), aspect.getOffsetY(),
                                p.viewSystem_, p.axisLabeller_,
@@ -244,6 +277,20 @@ public class SkySurfaceFactory
                                   ranges );
     }
 
+    public ConfigMap getAspectConfig( Surface surf ) {
+        ConfigMap config = new ConfigMap();
+        if ( surf instanceof SkySurface ) {
+            SkySurface ssurf = (SkySurface) surf;
+            SkyFov fov = ssurf.getProjection().getFov( ssurf );
+            if ( fov != null ) {
+                config.put( LON_KEY, new Double( fov.getLonDeg() ) );
+                config.put( LAT_KEY, new Double( fov.getLatDeg() ) );
+                config.put( FOV_RADIUS_KEY, new Double( fov.getRadiusDeg() ) );
+            }
+        }
+        return config;
+    }
+
     public Range[] readRanges( Profile profile, PlotLayer[] layers,
                                DataStore dataStore ) {
         PointCloud pointCloud =
@@ -300,7 +347,12 @@ public class SkySurfaceFactory
      */
     private static ConfigKey<Projection> createProjectionKey() {
         ConfigMeta meta = new ConfigMeta( "projection", "Projection" );
-        Projection[] projs = SkyAspect.getProjections();
+        Projection[] projections = new Projection[] {
+            // new HemisphereProjection(),  // toy projection, inferior to Sin
+            SinProjection.INSTANCE,
+            SkyviewProjection.AIT,
+            SkyviewProjection.CAR1,
+        };
         meta.setShortDescription( "Sky coordinate projection" );
         meta.setXmlDescription( new String[] {
             "<p>Sky projection used to display the plot.",
@@ -308,7 +360,7 @@ public class SkySurfaceFactory
         } );
         OptionConfigKey<Projection> key =
                 new OptionConfigKey<Projection>( meta, Projection.class,
-                                                 projs ) {
+                                                 projections ) {
             public String valueToString( Projection proj ) {
                 return proj.getProjectionName().toLowerCase();
             }
