@@ -121,7 +121,6 @@ public enum FixedCode implements ReportCode {
     E_QFAA( "Query failure" ),
     E_QST1( "Multiple pre-table QUERY_STATUS INFOs" ),
     E_QST2( "Multiple post-table QUERY_STATUS INFOs" ),
-    E_QTYP( "Query/result column type mismatch" ),
     E_RALC( "RDFa Lite rules violated" ),
     E_RANG( "ObsCore values out of range" ),
     E_RDPH( "Job phase read failure" ),
@@ -160,8 +159,7 @@ public enum FixedCode implements ReportCode {
     W_CEZZ( "Compression" ),
     W_CIDX( "Index flag mismatch" ),
     W_CLUN( "Columns content" ),
-    W_CPID( "Non-IdentifierURI dataModel" ),
-    W_CTYP( "Datatype mismatch" ),
+    W_CTYP( "Datatype possible mismatch" ),
     W_CUCD( "UCD mismatch" ),
     W_CULF( "Custom language feature type" ),
     W_CUNI( "Unit mismatch" ),
@@ -172,6 +170,7 @@ public enum FixedCode implements ReportCode {
     W_DSUC( "Non-error return from duff query" ),
     W_EX00( "No examples in examples document" ),
     W_EXUL( "Undeclared query language" ),
+    W_EXVC( "Potentially problematic examples RDFa vocab attribute" ),
     W_EXVL( "Example query does not validate" ),
     W_FKUN( "Keys content" ),
     W_FLUN( "Key columns content" ),
@@ -187,6 +186,7 @@ public enum FixedCode implements ReportCode {
     W_NOMS( "No error message text" ),
     W_NSOP( "ObsCore value not in suggested set" ),
     W_QERR( "Query failed" ),
+    W_QTYP( "Query/result column type possible mismatch" ),
     W_RDIO( "Resource read error" ),
     W_TBNF( "Tables endpoint missing" ),
     W_TBUN( "Tables content" ),
