@@ -56,6 +56,37 @@ public class FuncTest extends TestCase {
         assertEquals( 4, Arithmetic.round( 4.5 ) );
 
         assertEquals( 3.14f, Arithmetic.roundDecimal( Math.PI, 2 ) );
+
+        assertEquals( 3, Arithmetic.mod( 23, 10 ) );
+        assertEquals( 3, Arithmetic.mod( 23, -10 ) );
+        assertEquals( -3, -23 % 10 );
+        assertEquals( 7, Arithmetic.mod( -23, 10 ) );
+        assertEquals( 0, Arithmetic.mod( 320, 16 ) );
+        assertEquals( 0, Arithmetic.mod( -320, 16 ) );
+        assertEquals( 0.5, Arithmetic.mod( 5.5, 1.25 ) );
+
+        assertEquals( 0.5, Arithmetic.phase( 112.5, 25 ) );
+        assertEquals( 0.75, Arithmetic.phase( 7, 4 ) );
+        assertEquals( 0.8, Arithmetic.phase( -1000.5, 2.5 ) );
+        assertEquals( 0, Arithmetic.phase( -3300, 33 ) );
+
+        assertEquals( 0.5, Arithmetic.phase( 112.5, 25, 0 ) );
+        assertEquals( 0.03, Arithmetic.phase( 5003, 100, 0 ) );
+        assertEquals( 0.01, Arithmetic.phase( 5003, 100, 2 ) );
+        assertEquals( 0.99, Arithmetic.phase( 5003, 100, 4 ) );
+
+        assertEquals( 1.0, Arithmetic.phase( -8.6, 0.2, 0, 0.5 ),
+                      1e-9 );
+        assertEquals( 0.0, Arithmetic.phase( 8.6125, 0.2, 0.0125, -0.7 ),
+                      1e-9 );
+        assertEquals( -0.5, Arithmetic.phase( 8.6125, 0.2, 0.1125, -0.7 ),
+                      1e-9 );
+        assertEquals( 99.2, Arithmetic.phase( 23, 10, 1, 99 ) );
+    }
+
+    private static double maxtedPhase( double t, double period, double t0,
+                                       double phase0 ) {
+        return ((1 - phase0 + ((t-t0)/period % 1)) % 1) + phase0;
     }
 
     public void testList() {
@@ -502,6 +533,32 @@ public class FuncTest extends TestCase {
 
         assertEquals( "some text", Strings.trim( "  some text  " ) );
         assertEquals( "some text", Strings.trim( "some text" ) );
+
+        // These examples from sec 3.5.1 of IAU-endorsed document
+        // "Specifications concerning designations" at
+        // http://cds.u-strasbg.fr/vizier/Dic/iau-spec.htx
+        checkDesig( "14:26:48", "+69:50:00", "RX J1426.8+6950" );
+        checkDesig( "13:02:00", "-63:50:00", "PSR J1302-6350" );
+        checkDesig( "17:49:37", "-28:03:52", "PN G001.2-00.3" );
+
+        checkDesig( "00:48:00", "-42:42:00", "QSO J0048-427" );
+        checkDesig( "00:51:08", "-42:26:29", "QSO 004848-4242.8" );
+        checkDesig( "12:00:00", "+45:00:00", "PSR J120000.0+450000.0" );
+        checkDesig( "12:02:33", "+44:43:18", "PSR B120000.0+450000.0" );
+        checkDesig( "12:02:33", "+44:43:18", "PSR 120000.0+450000.0 (O-RLY)" );
+
+        assertEquals( null, Strings.desigToIcrs( "NGC 4993" ) );
+        assertTrue( Double.isNaN( Strings.desigToRa( "HIP Z190012-230210" ) ) );
+        assertTrue( Double.isNaN( Strings.desigToDec( "TYC J190012230210" ) ) );
+    }
+
+    private void checkDesig( String raSex, String decSex, String desig ) {
+        assertEquals( raSex,
+                      CoordsDegrees
+                     .degreesToHms( Strings.desigToRa( desig ) ) );
+        assertEquals( decSex,
+                      CoordsDegrees
+                     .degreesToDms( Strings.desigToDec( desig ) ) );
     }
 
     public void testCoordsRadians() {
@@ -524,6 +581,15 @@ public class FuncTest extends TestCase {
                       CoordsRadians.posAngRadians( 0.1, 0, -0.1, 0 ), TINY );
         assertEquals( 0.0, CoordsRadians.posAngRadians( 1, .2, 1, .3 ), TINY );
 
+        assertEquals( 2.0,
+                      CoordsDegrees.polarDistanceDegrees( 50.5, -29, 1,
+                                                          50.5, -29, 3 ),
+                      TINY );
+        assertEquals( 4.0,
+                      CoordsDegrees.polarDistanceDegrees(  23, +18.5, 2,
+                                                          203, -18.5, 2 ),
+                      TINY );
+
         double ra1 = 0.1;
         double dec1 = 1.2;
         double ra2 = 0.2;
